Contributors
============

atomate2 was designed and developed by **Alex Ganose** |utf| |0000-0002-4486-3321|.

Additional contributions have been provided by:

| **Andrew Rosen** |arosen| |0000-0002-0141-7006|
| Miller Research Fellow
| University of California, Berkeley

.. |utf| image:: https://cdnjs.cloudflare.com/ajax/libs/octicons/8.5.0/svg/mark-github.svg
   :target: https://github.com/utf
   :width: 16
   :height: 16
   :alt: GitHub profile for utf
.. |0000-0002-4486-3321| image:: ../_static/orcid.svg
   :target: https://orcid.org/0000-0002-4486-3321
   :width: 16
   :height: 16
   :alt: ORCID profile for 0000-0002-4486-3321
.. |arosen| image:: https://cdnjs.cloudflare.com/ajax/libs/octicons/8.5.0/svg/mark-github.svg
   :target: https://github.com/arosen93
   :width: 16
   :height: 16
   :alt: GitHub commits from arosen93
.. |0000-0002-0141-7006| image:: ../_static/orcid.svg
   :target: https://orcid.org/0000-0002-0141-7006
   :width: 16
   :height: 16
   :alt: ORCID profile for 0000-0002-0141-7006
